import express from 'express';
import { 
  chatWithAI, 
  listIncompleteTasks, 
  recommendEvents, 
  comprehensiveAnalysis 
} from '../controllers/aiController.js';
import { protect } from '../middleware/authMiddleware.js';

const router = express.Router();

// 修改路由以从查询参数获取token
const extractToken = (req, res, next) => {
  if (req.query.token) {
    req.headers.authorization = `Bearer ${req.query.token}`;
  }
  next();
};

router.get('/chat', extractToken, protect, chatWithAI);
router.get('/list-incomplete-tasks', extractToken, protect, listIncompleteTasks);
router.get('/recommend-events', extractToken, protect, recommendEvents);
router.get('/comprehensive-analysis', extractToken, protect, comprehensiveAnalysis);

export default router;