import express from 'express';
import { 
  getTasks, 
  createTask, 
  getTaskById, 
  updateTask, 
  deleteTask,
  getWeeklyStats,
  getImportanceStats
} from '../controllers/taskController.js';
import { protect } from '../middleware/authMiddleware.js';

const router = express.Router();

router.route('/')
  .get(protect, getTasks)
  .post(protect, createTask);

router.route('/:id')
  .get(protect, getTaskById)
  .put(protect, updateTask)
  .delete(protect, deleteTask);

router.get('/stats/weekly', protect, getWeeklyStats);
router.get('/stats/importance', protect, getImportanceStats);

export default router;