import express from 'express';
import cors from 'cors';
import dotenv from 'dotenv';
import { fileURLToPath } from 'url';
import { dirname, join } from 'path';
import userRoutes from './routes/userRoutes.js';
import taskRoutes from './routes/taskRoutes.js';
import scheduleRoutes from './routes/scheduleRoutes.js';
import aiRoutes from './routes/aiRoutes.js';
import moodRoutes from './routes/moodRoutes.js';

// 加载环境变量
dotenv.config();

const app = express();

// 中间件
app.use(cors());
app.use(express.json());

// 路由
app.use('/api/users', userRoutes);
app.use('/api/tasks', taskRoutes);
app.use('/api/schedules', scheduleRoutes);
app.use('/api/ai', aiRoutes);
app.use('/api/moods', moodRoutes);

// 基础路由
app.get('/', (req, res) => {
  res.send('API 运行中...');
});

// 端口配置
const PORT = process.env.PORT || 5000;

app.listen(PORT, () => {
  console.log(`服务器在端口 ${PORT} 上运行`);
});