import React, { useEffect, useState } from 'react';
import { Radio, Space, Tooltip } from 'antd';
import {
  FrownOutlined,
  MehOutlined,
  SmileOutlined
} from '@ant-design/icons';

const MoodSelector = ({ value, onChange }) => {
  const [isMobile, setIsMobile] = useState(false);
  
  // 检测是否为移动设备
  useEffect(() => {
    const checkIfMobile = () => {
      setIsMobile(window.innerWidth <= 768);
    };
    
    // 初始检查
    checkIfMobile();
    
    // 添加窗口大小变化监听
    window.addEventListener('resize', checkIfMobile);
    
    // 清理监听器
    return () => window.removeEventListener('resize', checkIfMobile);
  }, []);
  
  // 心情图标和描述
  const moods = [
    { value: 1, icon: <FrownOutlined style={{ color: '#f87171' }} />, text: '非常糟糕' },
    { value: 2, icon: <FrownOutlined style={{ color: '#fb923c' }} />, text: '糟糕' },
    { value: 3, icon: <MehOutlined style={{ color: '#facc15' }} />, text: '一般' },
    { value: 4, icon: <SmileOutlined style={{ color: '#4ade80' }} />, text: '良好' },
    { value: 5, icon: <SmileOutlined style={{ color: '#34d399' }} />, text: '非常好' }
  ];

  return (
    <div className="py-2">
      <Radio.Group value={value} onChange={(e) => onChange(e.target.value)}>
        <Space size={isMobile ? "middle" : "large"} wrap={isMobile}>
          {moods.map(mood => (
            <Tooltip key={mood.value} title={mood.text}>
              <Radio.Button 
                value={mood.value} 
                style={{ 
                  display: 'flex', 
                  flexDirection: 'column', 
                  alignItems: 'center', 
                  justifyContent: 'center',
                  minWidth: isMobile ? 60 : 72,
                  minHeight: 50,
                  padding: isMobile ? '8px 5px' : 10,
                  borderRadius: 8,
                  boxSizing: 'border-box',
                  background: 'none',
                  margin: isMobile ? '5px 0' : 0
                }}
              >
                <span style={{ fontSize: isMobile ? '18px' : '22px', marginBottom: isMobile ? 5 : 10 }}>{mood.icon}</span>
                <span style={{ 
                  fontSize: isMobile ? '12px' : '14px', 
                  marginTop: 2,
                  whiteSpace: 'nowrap',
                  overflow: 'hidden',
                  textOverflow: 'ellipsis',
                  width: '100%',
                  textAlign: 'center'
                }}>{mood.text}</span>
              </Radio.Button>
            </Tooltip>
          ))}
        </Space>
      </Radio.Group>
      <div className="mt-4 text-gray-500 text-center text-sm">
        请选择今日心情，数据将用于跟踪您的情绪变化。
      </div>
    </div>
  );
};

export default MoodSelector;